@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from typing import Iterable, Any
+from typing import Any, Iterable
 
 __author__ = "Christian Heider Nielsen"
 __doc__ = r"""
@@ -14,12 +14,12 @@ __all__ = ["yield_and_map", "inner_map", "kw_map"]
 def yield_and_map(iterable: Iterable, level: int = 0, func: callable = print) -> Any:
     """
 
-    :param iterable:
-    :type iterable:
-    :param level:
-    :type level:
-    :param func:
-    :type func:"""
+  :param iterable:
+  :type iterable:
+  :param level:
+  :type level:
+  :param func:
+  :type func:"""
     if level == 0:
         for a in iterable:
             func(a)
@@ -40,12 +40,12 @@ def yield_and_map(iterable: Iterable, level: int = 0, func: callable = print) ->
 def inner_map(func: callable, iterable: Iterable, aggregate_yield: bool = True) -> Any:
     """
 
-    :param func:
-    :type func:
-    :param iterable:
-    :type iterable:
-    :param aggregate_yield:
-    :type aggregate_yield:"""
+  :param func:
+  :type func:
+  :param iterable:
+  :type iterable:
+  :param aggregate_yield:
+  :type aggregate_yield:"""
     if aggregate_yield:
         for a in iterable:
             yield [func(b) for b in a]
@@ -58,12 +58,12 @@ def inner_map(func: callable, iterable: Iterable, aggregate_yield: bool = True)
 def kw_map(func: callable, kw: str, iterable: Iterable) -> Any:
     """
 
-    :param func:
-    :type func:
-    :param kw:
-    :type kw:
-    :param iterable:
-    :type iterable:"""
+  :param func:
+  :type func:
+  :param kw:
+  :type kw:
+  :param iterable:
+  :type iterable:"""
     for a in iterable:
         yield func(**{kw: a})
 
