@@ -7,12 +7,13 @@ __doc__ = r"""
            Created on 17-09-2020
            """
 
+from pathlib import Path
+
 from .. import INCLUDE_PROJECT_READMES
 
 if INCLUDE_PROJECT_READMES:
-    import pathlib
 
-    with open(pathlib.Path(__file__).parent / "README.md", "r") as this_init_file:
+    with open(Path(__file__).parent / "README.md", "r") as this_init_file:
         __doc__ += this_init_file.read()
 
 from .conversion import *
