@@ -7,7 +7,7 @@ __doc__ = r"""
            Created on 17/07/2020
            """
 
-__all__ = ["recursive_flatten_numpy"]
+__all__ = ["recursive_flatten_numpy", "MyNdArray"]
 
 from typing import Sequence
 
@@ -16,11 +16,18 @@ import numpy
 
 def recursive_flatten_numpy(nested: Sequence) -> numpy.ndarray:
     """
-    """
+"""
     return numpy.array(nested).ravel()
 
 
+class MyNdArray(numpy.ndarray):
+    @property
+    def conjugate_transpose(self):
+        return self.conj().T
+
+
 if __name__ == "__main__":
 
     print(recursive_flatten_numpy([[numpy.zeros((2, 2))], [numpy.zeros((2, 2))]]))
     print(recursive_flatten_numpy(numpy.zeros((2, 2))))
+    print(numpy.random.random((3, 3)).view(MyNdArray).conjugate_transpose)
