@@ -10,14 +10,15 @@ __doc__ = r"""
 __all__ = ["compute_color_for_labels"]
 
 from typing import Tuple
-from warg import Triple
+
+from warg import TripleNumber
 
 
 def compute_color_for_labels(
-    label: int, palette: Triple = (2 ** 11 - 1, 2 ** 15 - 1, 2 ** 20 - 1)
+    label: int, palette: TripleNumber = (2 ** 11 - 1, 2 ** 15 - 1, 2 ** 20 - 1)
 ) -> Tuple:
     """
-    Simple function that adds fixed color depending on the class"""
+  Simple function that adds fixed color depending on the class"""
     return (
         *[int(((label > 0) * p * (label ** 2 - label + 1)) % 255) for p in palette],
     )
