@@ -8,12 +8,12 @@ __doc__ = r"""
            """
 
 from pathlib import Path
-from typing import Sequence, Tuple, Union
+from typing import Optional, Sequence, Tuple, Union
+
 
-import PIL.ImageDraw as ImageDraw
-import PIL.ImageFont as ImageFont
 import numpy
-from PIL import Image
+from PIL import Image, ImageDraw, ImageFont
+
 from draugr.opencv_utilities.bounding_boxes.colors import compute_color_for_labels
 from draugr.opencv_utilities.opencv_draw import draw_masks
 from draugr.python_utilities.colors import RGB
@@ -37,7 +37,7 @@ def draw_single_box(
     color_fill_score: bool = False,
 ) -> Image.Image:
     """
-    """
+  """
     if not isinstance(image, ImageDraw.ImageDraw):
         assert isinstance(image, Image.Image)
         if image.mode != "RGBA":
@@ -93,9 +93,9 @@ def draw_bounding_boxes(
     image: Union[numpy.ndarray, Image.Image],
     boxes: numpy.ndarray,
     *,
-    labels: numpy.ndarray = None,
-    scores: numpy.ndarray = None,
-    categories: Sequence[str] = None,
+    labels: Optional[numpy.ndarray] = None,
+    scores: Optional[numpy.ndarray] = None,
+    categories: Optional[Sequence[str]] = None,
     outline_width: int = 2,
     outline_alpha: float = 0.5,
     score_color_fill: bool = False,
@@ -104,19 +104,19 @@ def draw_bounding_boxes(
     mode="RGBA",
 ) -> numpy.ndarray:
     """Draw bounding boxes(labels, scores) on image
-    Args:
-    image: numpy array image, shape should be (height, width, channel)
-    boxes: bboxes, shape should be (N, 4), and each row is (xmin, ymin, xmax, ymax), NOT NORMALISED!
-    labels: labels, shape: (N, )
-    scores: label scores, shape: (N, )
-    class_name_map: list or dict, map class id to class name for visualization.
-    width: box width
-    alpha: text background alpha
-    fill: fill box or not
-    font: text font
-    score_format: score format
-    Returns:
-    An image with information drawn on it."""
+  Args:
+  image: numpy array image, shape should be (height, width, channel)
+  boxes: bboxes, shape should be (N, 4), and each row is (xmin, ymin, xmax, ymax), NOT NORMALISED!
+  labels: labels, shape: (N, )
+  scores: label scores, shape: (N, )
+  class_name_map: list or dict, map class id to class name for visualization.
+  width: box width
+  alpha: text background alpha
+  fill: fill box or not
+  font: text font
+  score_format: score format
+  Returns:
+  An image with information drawn on it."""
     boxes = numpy.array(boxes)
     num_boxes = boxes.shape[0]
     if isinstance(image, Image.Image):
@@ -162,7 +162,7 @@ if __name__ == "__main__":
 
     def a():
         """
-        """
+    """
         from matplotlib import pyplot
         import pickle
         from neodroidvision.data.datasets.supervised.detection.coco import COCODataset
@@ -187,7 +187,7 @@ if __name__ == "__main__":
 
     def b():
         """
-        """
+    """
         from matplotlib import pyplot
 
         data_root = Path.home() / "Data" / "PennFudanPed" / "PNGImages"
