@@ -12,33 +12,16 @@ __doc__ = r"""
 __all__ = [
     "uint_nhwc_to_nchw_float_batch",
     "float_nchw_to_nhwc_uint_batch",
-    "hwc_to_chw_tensor",
-    "chw_to_hwc_tensor",
     "float_chw_to_hwc_uint_tensor",
     "uint_hwc_to_chw_float_tensor",
 ]
 
-
-def hwc_to_chw_tensor(inp: torch.Tensor) -> torch.Tensor:
-    """
-
-    :param inp:
-    :type inp:
-    :return:
-    :rtype:"""
-    assert len(inp.shape) == 3
-    return inp.permute(2, 0, 1)
-
-
-def chw_to_hwc_tensor(inp: torch.Tensor) -> torch.Tensor:
-    """
-
-    :param inp:
-    :type inp:
-    :return:
-    :rtype:"""
-    assert len(inp.shape) == 3
-    return inp.permute(1, 2, 0)
+from draugr.torch_utilities.tensors.dimension_order import (
+    chw_to_hwc_tensor,
+    hwc_to_chw_tensor,
+    nchw_to_nhwc_tensor,
+    nhwc_to_nchw_tensor,
+)
 
 
 def uint_hwc_to_chw_float_tensor(
@@ -46,12 +29,12 @@ def uint_hwc_to_chw_float_tensor(
 ) -> torch.Tensor:
     """
 
-    :param inp:
-    :type inp:
-    :param normalise:
-    :type normalise:
-    :return:
-    :rtype:"""
+  :param inp:
+  :type inp:
+  :param normalise:
+  :type normalise:
+  :return:
+  :rtype:"""
     if normalise:
         inp = (inp / 255.0).clamp(0, 1)
     return hwc_to_chw_tensor(inp)
@@ -62,12 +45,12 @@ def float_chw_to_hwc_uint_tensor(
 ) -> torch.Tensor:
     """
 
-    :param inp:
-    :type inp:
-    :param unnormalise:
-    :type unnormalise:
-    :return:
-    :rtype:"""
+  :param inp:
+  :type inp:
+  :param unnormalise:
+  :type unnormalise:
+  :return:
+  :rtype:"""
     inp = chw_to_hwc_tensor(inp)
     if unnormalise:
         inp = (inp * 255.0).clamp(0, 255)
@@ -79,16 +62,15 @@ def uint_nhwc_to_nchw_float_batch(
 ) -> torch.Tensor:
     """
 
-    :param inp:
-    :type inp:
-    :param normalise:
-    :type normalise:
-    :return:
-    :rtype:"""
-    assert len(inp.shape) == 4
+  :param inp:
+  :type inp:
+  :param normalise:
+  :type normalise:
+  :return:
+  :rtype:"""
     if normalise:
         inp = (inp / 255.0).clamp(0, 1)
-    return inp.permute(0, 3, 1, 2)
+    return nhwc_to_nchw_tensor(inp)
 
 
 def float_nchw_to_nhwc_uint_batch(
@@ -96,14 +78,13 @@ def float_nchw_to_nhwc_uint_batch(
 ) -> torch.Tensor:
     """
 
-    :param inp:
-    :type inp:
-    :param unnormalise:
-    :type unnormalise:
-    :return:
-    :rtype:"""
-    assert len(inp.shape) == 4
-    inp = inp.permute(0, 3, 1, 2)
+  :param inp:
+  :type inp:
+  :param unnormalise:
+  :type unnormalise:
+  :return:
+  :rtype:"""
+    inp = nchw_to_nhwc_tensor(inp)
     if unnormalise:
         inp = (inp * 255.0).clamp(0, 255)
     return inp.to(dtype=torch.uint8)
