@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+from enum import Enum
 from typing import Union
 
 import torch
@@ -19,50 +20,66 @@ __all__ = [
     "auto_select_available_cuda_device",
     "set_global_torch_device",
     "torch_clean_up",
+    "TorchDeviceEnum",
 ]
 
 
+class TorchDeviceEnum(Enum):
+    cpu = "cpu"
+    cuda = "cuda"
+    vulkan = "vulkan"
+
+
 def global_torch_device(
-    cuda_device_preference: Union[bool, str] = None,
+    device_preference: Union[bool, str, TorchDeviceEnum] = None,
     override: torch.device = None,
     verbose: bool = False,
 ) -> torch.device:
     """
 
-    first time call stores to device for global reference, later call must manually override
+first time call stores to device for global reference, later call must explicitly manually override!
 
-    :param verbose:
-    :type verbose:
-    :param cuda_device_preference:
-    :type cuda_device_preference:
-    :param override:
-    :type override:
-    :return:
-    :rtype:"""
+:param verbose:
+:type verbose:
+:param device_preference:
+:type device_preference:
+:param override:
+:type override:
+:return:
+:rtype:"""
     global GLOBAL_DEVICE
 
     if override is not None:
         GLOBAL_DEVICE = override
         if verbose:
             print(f"Overriding global torch device to {override}")
-    elif cuda_device_preference is not None:
-        if isinstance(cuda_device_preference, bool):
-            d = torch.device(
-                "cuda"
-                if torch.cuda.is_available() and cuda_device_preference
-                else "cpu"
-            )
-        elif isinstance(cuda_device_preference, str):
-            d = torch.device(cuda_device_preference)
+    elif device_preference is not None:
+        if isinstance(device_preference, bool):
+            if torch.is_vulkan_available() and device_preference:
+                d_ = TorchDeviceEnum.vulkan
+            elif torch.cuda.is_available() and device_preference:
+                d_ = TorchDeviceEnum.cuda
+            else:
+                d_ = TorchDeviceEnum.cpu
+
+            d = torch.device(d_.value)
+        elif isinstance(device_preference, TorchDeviceEnum):
+            d = torch.device(device_preference.value)
+        elif isinstance(device_preference, str):
+            d = torch.device(device_preference)
         else:
             raise TypeError("not bool or str")
         if GLOBAL_DEVICE is None:
             GLOBAL_DEVICE = d
         return d
     elif GLOBAL_DEVICE is None:
-        GLOBAL_DEVICE = torch.device(
-            "cuda" if torch.cuda.is_available() and True else "cpu"
-        )
+        if torch.is_vulkan_available():
+            d_ = TorchDeviceEnum.vulkan
+        elif torch.cuda.is_available():
+            d_ = TorchDeviceEnum.cuda
+        else:
+            d_ = TorchDeviceEnum.cpu
+        GLOBAL_DEVICE = torch.device(d_.value)
 
     return GLOBAL_DEVICE
 
@@ -70,8 +87,8 @@ def global_torch_device(
 def set_global_torch_device(device: torch.device) -> None:
     """
 
-    :param device:
-    :return:"""
+:param device:
+:return:"""
     global GLOBAL_DEVICE
     GLOBAL_DEVICE = device
 
@@ -79,10 +96,10 @@ def set_global_torch_device(device: torch.device) -> None:
 def select_cuda_device(cuda_device_idx: int) -> torch.device:
     """
 
-    :param cuda_device_idx:
-    :type cuda_device_idx:
-    :return:
-    :rtype:"""
+:param cuda_device_idx:
+:type cuda_device_idx:
+:return:
+:rtype:"""
     num_cuda_device = torch.cuda.device_count()
     assert num_cuda_device > 0
     assert cuda_device_idx < num_cuda_device
@@ -93,8 +110,8 @@ def select_cuda_device(cuda_device_idx: int) -> torch.device:
 def get_gpu_usage_mb():
     """
 
-    :return:
-    :rtype:"""
+:return:
+:rtype:"""
 
     import subprocess
 
@@ -118,7 +135,7 @@ Values are memory usage as integers in MB.
 def torch_clean_up() -> None:
     r"""**Destroy cuda state by emptying cache and collecting IPC.**
 
-    Consecutively calls `torch.cuda.empty_cache()` and `torch.cuda.ipc_collect()`."""
+Consecutively calls `torch.cuda.empty_cache()` and `torch.cuda.ipc_collect()`."""
 
     torch.cuda.empty_cache()
     torch.cuda.ipc_collect()
@@ -128,14 +145,15 @@ def auto_select_available_cuda_device(
     expected_memory_usage_mb: int = 1024,
 ) -> torch.device:
     r"""
-    Auto selects the device with highest compute capability and with the requested memory available
+Auto selects the device with highest compute capability and with the requested memory available
 
-    :param expected_memory_usage_mb:
-    :type expected_memory_usage_mb:
-    :return:
-    :rtype:"""
+:param expected_memory_usage_mb:
+:type expected_memory_usage_mb:
+:return:
+:rtype:"""
 
     num_cuda_device = torch.cuda.device_count()
+    # TODO: torch.vulkan.device_count() variant in the future
     assert num_cuda_device > 0
     """
 print(torch.cuda.cudart())
@@ -174,32 +192,36 @@ if __name__ == "__main__":
 
     def stest_override():
         """
-        """
+"""
         print(global_torch_device(verbose=True))
         print(
             global_torch_device(
-                override=global_torch_device(
-                    cuda_device_preference=False, verbose=True
-                ),
+                override=global_torch_device(device_preference=False, verbose=True),
                 verbose=True,
             )
         )
         print(global_torch_device(verbose=True))
-        print(global_torch_device(cuda_device_preference=True))
+        print(global_torch_device(device_preference=True))
         print(global_torch_device())
         print(
             global_torch_device(
-                override=global_torch_device(cuda_device_preference=True, verbose=True)
+                override=global_torch_device(device_preference=True, verbose=True)
             )
         )
         print(global_torch_device())
 
     def a():
         """
-        """
+"""
         print(global_torch_device())
         print(auto_select_available_cuda_device())
 
+    def b():
+        """
+"""
+        print(global_torch_device(TorchDeviceEnum.vulkan))
+
     # stest_override()
 
     print(global_torch_device(False).type)
+    b()
