@@ -7,6 +7,8 @@ __all__ = [
     "TestingScalars",
     "TestingCurves",
     "TestingTables",
+    "should_plot_y_log_scale",
+    "should_smooth_series",
 ]
 
 
@@ -48,5 +50,31 @@ class TestingTables(Enum):
     test_support = "test_support"
 
 
+def should_plot_y_log_scale(tag: Enum) -> bool:
+    """
+
+    :param tag:
+    :return:
+    """
+    if tag is TrainingScalars.training_loss:
+        return True
+    elif tag is TrainingScalars.validation_loss:
+        return True
+    return False
+
+
+def should_smooth_series(tag: Enum) -> bool:
+    """
+
+    :param tag:
+    :return:
+    """
+    if tag is TrainingScalars.training_loss:
+        return True
+    elif tag is TrainingScalars.validation_loss:
+        return True
+    return False
+
+
 if __name__ == "__main__":
     print(TrainingScalars.training_loss.value)
